@@ -24,13 +24,6 @@
 
 namespace Minuet
 {
-IUiController::IUiController(QObject *parent)
-    : QObject(parent)
-{
-}
-
-IUiController::~IUiController()
-{
-}
+IUiController::IUiController(QObject *parent) : QObject(parent) {}
 
 }
